from setuptools import setup

setup(name='dsnd_probability',
      version='1.2',
      description='Gaussian and Binomial distributions',
      packages=['dsnd_distributions'],
      author = 'Satyendra Jaladi',
      author_email = 'sam.satya38@gmail.com',
      zip_safe=False)
